@@ -46,11 +46,7 @@ class Wlasl(tfds.core.GeneratorBasedBuilder):
             "signer": tfds.features.Text(),
             "gloss": tfds.features.Text(),
             "gloss_variation": tf.int32,
-            "video_file": {
-                "start": tf.int32,
-                "end": tf.int32,
-                "remote": tfds.features.Text(),
-            },
+            "video_file": {"start": tf.int32, "end": tf.int32, "remote": tfds.features.Text(),},
             "fps": tf.int32,
             "bbox": tfds.features.BBoxFeature(),
         }
